@@ -120,6 +120,10 @@ echo "Installing pgAdmin 4..."
 dnf install -y https://ftp.postgresql.org/pub/pgadmin/pgadmin4/yum/pgadmin4-redhat-repo-2-1.noarch.rpm
 dnf install -y pgadmin4-web
 
+# Install required Python module for pgAdmin setup
+echo "Installing required Python modules for pgAdmin..."
+pip3 install typer
+
 # Configure pgAdmin 4
 echo "Configuring pgAdmin 4..."
 # Create config_local.py for pgAdmin
@@ -135,8 +139,8 @@ EOF
 # Set up pgAdmin directories
 mkdir -p /var/lib/pgadmin
 mkdir -p /var/log/pgadmin
-chown -R apache:apache /var/lib/pgadmin
-chown -R apache:apache /var/log/pgadmin
+chown -R root:root /var/lib/pgadmin
+chown -R root:root /var/log/pgadmin
 
 # Configure Apache for pgAdmin
 cat > /etc/httpd/conf.d/pgadmin4.conf << 'EOF'
@@ -151,6 +155,15 @@ WSGIScriptAlias /pgadmin4 /usr/pgadmin4/web/pgAdmin4.wsgi
 </Directory>
 EOF
 
+# Run pgAdmin setup
+echo "Setting up pgAdmin 4 configuration..."
+PGADMIN_SETUP_EMAIL='admin@localhost' PGADMIN_SETUP_PASSWORD="$postgres_password" /usr/pgadmin4/bin/setup-web.sh --yes
+if [ $? -eq 0 ]; then
+    echo "✓ pgAdmin 4 setup completed successfully"
+else
+    echo "⚠ pgAdmin 4 setup failed - continuing anyway"
+fi
+
 # Install ProFTPD package (configuration happens after database setup)
 echo "Installing ProFTPD..."
 dnf install -y proftpd proftpd-mysql
