@@ -133,6 +133,9 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="./phpmyadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
                         <i class="fa fa-database me-3"></i>phpMyAdmin
                     </a>
+                    <a href="./pgadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
+                        <i class="fa fa-database me-3 text-success"></i>pgAdmin 4
+                    </a>
                     <a href="index.php?page=database-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'database-management' ? 'active' : ''; ?>">
                         <i class="fa fa-database me-3"></i>MySQL Management
                     </a>
